package com.ruoyi.postCheck.service;

import com.ruoyi.common.core.domain.AjaxResult;

/**
 * 发送邮件业务层
 *
 * @author csg
 * @date 2024-01-01
 */
public interface IPostSendMailService {
    /**
     * 邮件通知-岗位责任制清
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postListSendMail(String serviceType, Long serviceId);

    /**
     * 邮件通知-岗检方案
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postProgrammeSendMail(String serviceType, Long serviceId);

    /**
     * 邮件通知-岗检计划
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postPalnSendMail(String serviceType, Long serviceId);

    /**
     * 邮件通知-岗检表
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postCheckedSendMail(String serviceType, Long serviceId);
    /**
     * 邮件通知-问题
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postProblemSendMail(String serviceType, Long serviceId);
    /**
     * 邮件通知-能部门互评
     * 邮件通知-生产部门日常评分
     *
     * @param serviceType 业务类型
     * @param serviceId   业务表单ID
     * @return
     */
    AjaxResult postAssessmentRatingOtherSendMail(String serviceType, Long serviceId);
}
